@@ -1,5 +1,5 @@
 from .device_registry import DeviceRegistry
 from .eval import RemoteError
-from .config_store import Config
+from .config import Config
 from .utilities import *
 from .version import __version__
